@@ -40,14 +40,12 @@
       'Systemd::CommonElements'
     ],
     'name' => 'Systemd::Service',
-    'read_config' => [
-      {
-        'auto_create' => '1',
-        'auto_delete' => '1',
-        'backend' => 'Systemd::Unit',
-        'file' => '&index.service'
-      }
-    ]
+    'rw_config' => {
+      'auto_create' => '1',
+      'auto_delete' => '1',
+      'backend' => 'Systemd::Unit',
+      'file' => '&index.service'
+    }
   }
 ]
 ;
